<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>ArrowToolOptionsBox</name>
    <message>
        <source>Pick:</source>
        <translation>Piquer:</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Z:</source>
        <translation>Z:</translation>
    </message>
    <message>
        <source>SO:</source>
        <translation>OE:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Échelle</translation>
    </message>
    <message>
        <source>Global:</source>
        <translation>Globale:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Maintain:</source>
        <translation>Maintenir:</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Cisaillement</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Centre</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">Verrouiller</translation>
    </message>
    <message>
        <source>(</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation type="unfinished">Position du Centre</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Object Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Object Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Object Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Object Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Épaisseur</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="vanished">Dureté:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation type="vanished">Précision:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation type="vanished">Sélective</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="vanished">Paramètre Prédéfini:</translation>
    </message>
    <message>
        <source>Break Sharp Angles</source>
        <translation type="vanished">Couper les Angles Aigus</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation type="vanished">Mode Crayon</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Sensibilité à la Pression</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation type="vanished">Extrémité</translation>
    </message>
    <message>
        <source>Join</source>
        <translation type="vanished">Sommet</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation type="vanished">Pointe:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="obsolete">Magnétisme</translation>
    </message>
</context>
<context>
    <name>BrushToolOptionsBox</name>
    <message>
        <source>Preset Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuler</translation>
    </message>
</context>
<context>
    <name>ControlPointEditorTool</name>
    <message>
        <source>Auto Select Drawing</source>
        <translation>Sélection Automatique du Dessin</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Magnétisme</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Type:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ControlPointSelection</name>
    <message>
        <source>Set Linear Control Point</source>
        <translation>Définir le Point de Contrôle comme Linéaire</translation>
    </message>
    <message>
        <source>Set Nonlinear Control Point</source>
        <translation>Définir le Point de Contrôle comme Non Linéaire</translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTool</name>
    <message>
        <source>Scale Constraint:</source>
        <translation>Contrainte de l&apos; Échelle</translation>
    </message>
    <message>
        <source>Auto Select Column</source>
        <translation>Sélection Automatique de la Colonne</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Clé Globale</translation>
    </message>
    <message>
        <source>Lock Center X</source>
        <translation>Verrouiller le Centre X</translation>
    </message>
    <message>
        <source>Lock Center Y</source>
        <translation>Verrouiller le Centre Y</translation>
    </message>
    <message>
        <source>Lock Position X</source>
        <translation>Verrouiller la Position X</translation>
    </message>
    <message>
        <source>Lock Position Y</source>
        <translation>Verrouiller la Position Y</translation>
    </message>
    <message>
        <source>Lock Rotation</source>
        <translation>Verrouiller la Rotation</translation>
    </message>
    <message>
        <source>Lock Shear H</source>
        <translation>Verrouiller le Cisaillement H</translation>
    </message>
    <message>
        <source>Lock Shear V</source>
        <translation>Verrouiller la Cisaillement V</translation>
    </message>
    <message>
        <source>Lock Scale H</source>
        <translation>Verrouiller l&apos; Échelle H</translation>
    </message>
    <message>
        <source>Lock Scale V</source>
        <translation>Verrouiller l&apos; Échelle V</translation>
    </message>
    <message>
        <source>Lock Global Scale</source>
        <translation>Verrouiller l&apos; Échelle Globale</translation>
    </message>
    <message>
        <source>X and Y Positions</source>
        <translation>Positions X et Y</translation>
    </message>
    <message>
        <source>Z Position</source>
        <translation>Position Z</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>OE:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>Global Scale</source>
        <translation>Échelle Globale</translation>
    </message>
    <message>
        <source>Horizontal and Vertical Scale</source>
        <translation>Échelle Horizontale et Verticale</translation>
    </message>
    <message>
        <source>Shear</source>
        <translation>Cisaillement</translation>
    </message>
    <message>
        <source>Center Position</source>
        <translation>Position du Centre</translation>
    </message>
    <message>
        <source>Active Axis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A/R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mass</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pegbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished">Position</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished">Échelle</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished">Centre</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureté:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Sélective</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverser</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Intervalle</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Mode Crayon</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segment</source>
        <translation type="unfinished">Segment</translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease In/Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FillTool</name>
    <message>
        <source>Frame Range</source>
        <translation>Intervalle</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Sélective</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Onion Skin</source>
        <translation>Pelure d&apos; Oignon</translation>
    </message>
    <message>
        <source>Fill Depth</source>
        <translation>Profondeur de Remplissage </translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Segment</translation>
    </message>
    <message>
        <source>Autopaint Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Gap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pick+Freehand</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FingerTool</name>
    <message>
        <source>Size:</source>
        <translation type="unfinished">Taille:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation type="unfinished">Inverser</translation>
    </message>
</context>
<context>
    <name>FullColorBrushTool</name>
    <message>
        <source>Thickness</source>
        <translation type="vanished">Épaisseur</translation>
    </message>
    <message>
        <source>Pressure Sensitivity</source>
        <translation type="vanished">Sensibilité à la Pression</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="vanished">Opacité:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureté:</translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Paramètre Prédéfini:</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullColorEraserTool</name>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacité:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureté:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Inverser</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Intervalle</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullColorFillTool</name>
    <message>
        <source>Fill Depth</source>
        <translation type="unfinished">Profondeur de Remplissage </translation>
    </message>
</context>
<context>
    <name>HandToolOptionsBox</name>
    <message>
        <source>Reset Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HookTool</name>
    <message>
        <source>Snap</source>
        <translation>Magnétisme</translation>
    </message>
</context>
<context>
    <name>MagnetTool</name>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
</context>
<context>
    <name>PaintBrushTool</name>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Sélective</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PinchTool</name>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Corner:</source>
        <translation>Angle:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
</context>
<context>
    <name>PlasticTool</name>
    <message>
        <source>Build Skeleton</source>
        <translation>Créer Squelette</translation>
    </message>
    <message>
        <source>Paint Rigid</source>
        <translation>Dessiner la Rigidité</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation>Animer</translation>
    </message>
    <message>
        <source>Rigid</source>
        <translation>Rigide</translation>
    </message>
    <message>
        <source>Flex</source>
        <translation>Flexible</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Vertex Name:</source>
        <translation>Nom Vertex:</translation>
    </message>
    <message>
        <source>Allow Stretching</source>
        <translation>Permettre Stretching</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Épaisseur</translation>
    </message>
    <message>
        <source>Keep Distance</source>
        <translation>Garder Distance</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Clé Globale</translation>
    </message>
    <message>
        <source>A group of skeletons already exists for current column. Replacing it will also substitute any existing vertex animation.

Do you want to continue?</source>
        <translation>Un groupe de squelettes existe déjà pour la colonne actuelle.Son remplacement éliminera toutes les animations des sommets.

Voulez-vous continuer?
</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Copy Skeleton</source>
        <translation>Copier Squelette</translation>
    </message>
    <message>
        <source>Paste Skeleton</source>
        <translation>Coller Squelette</translation>
    </message>
    <message>
        <source>Delete Vertex</source>
        <translation>Supprimer Sommet</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Définir une Clé</translation>
    </message>
    <message>
        <source>Set Rest Key</source>
        <translation>Définir une Clé de Reste</translation>
    </message>
    <message>
        <source>Set Global Key</source>
        <translation>Définir une Clé Globale</translation>
    </message>
    <message>
        <source>Set Global Rest Key</source>
        <translation>Définir une Clé Globale  de Reste </translation>
    </message>
    <message>
        <source>Show Mesh</source>
        <translation>Montrer Maille</translation>
    </message>
    <message>
        <source>Show Rigidity</source>
        <translation>Montrer Rigidité</translation>
    </message>
    <message>
        <source>Show SO</source>
        <translation>Montrer OE</translation>
    </message>
    <message>
        <source>Show Skeleton Onion Skin</source>
        <translation>Montrer Squelette en Pelure d&apos;Oignon </translation>
    </message>
    <message>
        <source>The previous vertex name will be discarded, and all associated keys will be lost.

Do you want to proceed?</source>
        <translation>Le nom précédent de ce sommet sera mis au rebut, et toutes les clés associées seront perdues.

Voulez-vous continuer?</translation>
    </message>
    <message>
        <source>Edit Mesh</source>
        <translation>Modifier Maille</translation>
    </message>
    <message>
        <source>Snap To Mesh</source>
        <translation>Aligner sur la Maille</translation>
    </message>
    <message>
        <source>Angle Bounds</source>
        <translation>Angle Limites</translation>
    </message>
    <message>
        <source>Swap Edge</source>
        <translation>Inverser Bord</translation>
    </message>
    <message>
        <source>Collapse Edge</source>
        <translation>Réduire Bord</translation>
    </message>
    <message>
        <source>Split Edge</source>
        <translation>Diviser Bord</translation>
    </message>
    <message>
        <source>Cut Mesh</source>
        <translation>Couper Mesh</translation>
    </message>
</context>
<context>
    <name>PlasticToolOptionsBox</name>
    <message>
        <source>Create Mesh</source>
        <translation>Créer Maille</translation>
    </message>
    <message>
        <source>Skeleton:</source>
        <translation>Squelette:</translation>
    </message>
    <message>
        <source>SO</source>
        <translation>OE:</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>Angle</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>Distance</translation>
    </message>
</context>
<context>
    <name>PrimitiveParam</name>
    <message>
        <source>Shape:</source>
        <translation>Forme:</translation>
    </message>
    <message>
        <source>Thickness:</source>
        <translation>Épaisseur:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacité:</translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation>Dureté:</translation>
    </message>
    <message>
        <source>Polygon Sides:</source>
        <translation>Côtés du Polygone:</translation>
    </message>
    <message>
        <source>Auto Group</source>
        <translation>Groupe Automatique</translation>
    </message>
    <message>
        <source>Auto Fill</source>
        <translation>Remplissage Automatique</translation>
    </message>
    <message>
        <source>Selective</source>
        <translation>Sélective</translation>
    </message>
    <message>
        <source>Pencil Mode</source>
        <translation>Mode Crayon</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Extrémité</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Sommet</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Pointe:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished">Taille:</translation>
    </message>
    <message>
        <source>Snap</source>
        <translation type="unfinished">Magnétisme</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MultiArc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation type="unfinished">Lisser</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PumpTool</name>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Précision:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Min:</source>
        <translation>Min:</translation>
    </message>
    <message>
        <source>Max:</source>
        <translation>Max:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>The copied selection cannot be pasted in the current drawing.</source>
        <translation>La sélection copiée ne peut pas être collée dans le dessin courant.</translation>
    </message>
    <message>
        <source>The current column is locked.</source>
        <translation>La colonne courante est verrouillée.</translation>
    </message>
    <message>
        <source>The current column is not visible in Camera Stand.</source>
        <translation type="vanished">La colonne actuelle n&apos;est pas visible dans Camera Stand.</translation>
    </message>
    <message>
        <source>It is not possible to edit the audio column.</source>
        <translation>Il n&apos;est pas possible de modifier la colonne audio.</translation>
    </message>
    <message>
        <source>It is not possible to edit the Magpie column.</source>
        <translation type="vanished">Il n&apos;est pas possible de modifier la colonne Magpie.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Level column.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur une colonne Niveau.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh column.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur une colonne Maille.</translation>
    </message>
    <message>
        <source>The current tool cannot be used in Level Strip mode.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé en mode Level Strip.</translation>
    </message>
    <message>
        <source>The current tool cannot be used to edit a motion path.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé pour modifier une trajectoire.</translation>
    </message>
    <message>
        <source>The current level is not editable.</source>
        <translation>Le niveau actuel n&apos;est pas modifiable.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Vector Level.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur un Niveau Vector.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Toonz Level.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur un Niveau Toonz.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Raster Level.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur un Niveau Raster.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a Mesh Level.</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur un Niveau Maille.</translation>
    </message>
    <message>
        <source>The current tool cannot be used on a mesh-deformed level</source>
        <translation>L&apos;outil actuel ne peut pas être utilisé sur un niveau Maille déformé.</translation>
    </message>
    <message>
        <source>The current frame is locked: any editing is forbidden.</source>
        <translation>Le cadre actuel est verrouillé, toute modification est interdite.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RGB Picker (R%1, G%2, B%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Gadget  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1   Level : %2  Frame : %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Stroke Tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Spline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deform Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transform Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Save Box : (X%1,Y%2,W%3,H%4)-&gt;(X%5,Y%6,W%7,H%8)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current column is hidden.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note columns can only be edited in the xsheet or timeline.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> to Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be updated. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be deleted. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be pasted. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be grouped. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be entered. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be ungrouped. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selection cannot be moved. It is not editable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap At Intersection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGBPickerTool</name>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGBPickerToolOptionsBox</name>
    <message>
        <source>Pick Screen</source>
        <translation>Pick Screen</translation>
    </message>
</context>
<context>
    <name>RasterSelectionTool</name>
    <message>
        <source>Modify Savebox</source>
        <translation>Modifier Savebox</translation>
    </message>
    <message>
        <source>No Antialiasing</source>
        <translation>Pas d&apos;anticrénelage</translation>
    </message>
</context>
<context>
    <name>RasterTapeTool</name>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translation>Distance:</translation>
    </message>
    <message>
        <source>Style Index:</source>
        <translation>Indice de Style:</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacité:</translation>
    </message>
    <message>
        <source>Frame Range</source>
        <translation>Intervalle</translation>
    </message>
    <message>
        <source>Angle:</source>
        <translation>Angle:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RotateTool</name>
    <message>
        <source>Rotate On Camera Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RotateToolOptionsBox</name>
    <message>
        <source>Reset Rotation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RulerToolOptionsBox</name>
    <message>
        <source>X:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished">H:</translation>
    </message>
    <message>
        <source>A:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>L:</source>
        <comment>ruler tool option</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freehand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectionToolOptionsBox</name>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>V:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Rotation</source>
        <translation>Rotation</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>Épaisseur</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Lier</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished">Échelle</translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished">Position</translation>
    </message>
    <message>
        <source>Flip Selection Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip Selection Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Selection Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Selection Right</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShiftTraceToolOptionBox</name>
    <message>
        <source>Reset Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Following</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Following Drawing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SkeletonTool</name>
    <message>
        <source>Show Only Active Skeleton</source>
        <translation>Afficher Uniquement le Squelette Actif</translation>
    </message>
    <message>
        <source>Global Key</source>
        <translation>Clé Globale</translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Reset Pinned Center</source>
        <translation>Réinitialiser les centres épinglés</translation>
    </message>
    <message>
        <source>Build Skeleton</source>
        <translation type="unfinished">Créer Squelette</translation>
    </message>
    <message>
        <source>Animate</source>
        <translation type="unfinished">Animer</translation>
    </message>
    <message>
        <source>Inverse Kinematics</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StylePickerTool</name>
    <message>
        <source>No current level.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current level has no available palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette must have more than one palette to be organized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation type="unfinished">Mode:</translation>
    </message>
    <message>
        <source>Passive Pick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Organize Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Areas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lines &amp; Areas</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StylePickerToolOptionsBox</name>
    <message>
        <source>With this option being activated, the picked style will be
moved to the end of the first page of the palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToonzRasterBrushTool</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hardness:</source>
        <translation type="unfinished">Dureté:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw Order:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Over All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Under All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation type="unfinished">Paramètre Prédéfini:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lock Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToonzVectorBrushTool</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accuracy:</source>
        <translation>Précision:</translation>
    </message>
    <message>
        <source>Smooth:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preset:</source>
        <translation>Paramètre Prédéfini:</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Break</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Extrémité</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Sommet</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Pointe:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snap</source>
        <translation>Magnétisme</translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In&amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Med</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackerTool</name>
    <message>
        <source>Width:</source>
        <translation>Largeur:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Hauteur:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
</context>
<context>
    <name>TypeTool</name>
    <message>
        <source>Font:</source>
        <translation>Police:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>Style:</translation>
    </message>
    <message>
        <source>Vertical Orientation</source>
        <translation>Orientation Verticale</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille:</translation>
    </message>
</context>
<context>
    <name>VectorSelectionTool</name>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Preserve Thickness</source>
        <translation>Préserver Épaisseur</translation>
    </message>
    <message>
        <source>Cap</source>
        <translation>Extrémité</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Sommet</translation>
    </message>
    <message>
        <source>Miter:</source>
        <translation>Pointe:</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style on Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same Style on Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundary Strokes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundaries on Selected Frames</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boundaries on Whole Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Butt cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Projecting cap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Miter join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bevel join</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include Intersection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VectorTapeTool</name>
    <message>
        <source>Smooth</source>
        <translation>Lisser</translation>
    </message>
    <message>
        <source>Join Vectors</source>
        <translation>Réunir les Vecteurs</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation></translation>
    </message>
    <message>
        <source>Mode:</source>
        <translation>Mode:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Endpoint to Endpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoint to Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line to Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomToolOptionsBox</name>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
